@@ -129,6 +129,7 @@ public class AMQConnection extends Closeable implements CommonConnection, Refere
     private final Object _failoverMutex = new Object();
 
     private final Object _sessionCreationLock = new Object();
+    private final ConnectAttemptListener _connectAttemptListener;
 
     /**
      * A channel is roughly analogous to a session. The server can negotiate the maximum number of channels per session
@@ -151,11 +152,7 @@ public class AMQConnection extends Closeable implements CommonConnection, Refere
 
     private String _clientName;
 
-    /** The user name to use for authentication */
-    private String _username;
-
-    /** The password to use for authentication */
-    private String _password;
+    private volatile String _username;
 
     /** The virtual path to connect to on the AMQ server */
     private String _virtualHost;
@@ -312,6 +309,13 @@ public class AMQConnection extends Closeable implements CommonConnection, Refere
 
     public AMQConnection(ConnectionURL connectionURL) throws QpidException
     {
+        this(connectionURL, null);
+    }
+
+    AMQConnection(final ConnectionURL connectionURL, final ConnectAttemptListener connectAttemptListener)
+            throws QpidException
+    {
+        _connectAttemptListener = connectAttemptListener;
         boolean success = false;
         try
         {
@@ -482,8 +486,6 @@ public class AMQConnection extends Closeable implements CommonConnection, Refere
             _connectionURL = connectionURL;
 
             _clientName = connectionURL.getClientName();
-            _username = connectionURL.getUsername();
-            _password = connectionURL.getPassword();
 
             setVirtualHost(connectionURL.getVirtualHost());
 
@@ -573,10 +575,12 @@ public class AMQConnection extends Closeable implements CommonConnection, Refere
             }
         }
         BrokerDetails brokerDetails = _failoverPolicy.getCurrentBrokerDetails();
+        BrokerDetails lastBrokerDetails = null;
         boolean retryAllowed = true;
         Exception connectionException = null;
         while (!isConnected() && retryAllowed && brokerDetails != null)
         {
+            lastBrokerDetails = brokerDetails;
             ProtocolVersion pe = null;
             try
             {
@@ -613,11 +617,17 @@ public class AMQConnection extends Closeable implements CommonConnection, Refere
                 }
                 else
                 {
-                    retryAllowed = _failoverPolicy.failoverAllowed();
-                    brokerDetails = _failoverPolicy.getNextBrokerDetails();
+                    if (repeatLastConnectAttempt(connectionException, brokerDetails))
+                    {
+                        brokerDetails = _failoverPolicy.getCurrentBrokerDetails();
+                    }
+                    else
+                    {
+                        retryAllowed = _failoverPolicy.failoverAllowed();
+                        brokerDetails = _failoverPolicy.getNextBrokerDetails();
+                    }
                     _protocolHandler.setStateManager(new AMQStateManager(_protocolHandler.getProtocolSession()));
                 }
-
             }
         }
         verifyClientID();
@@ -676,11 +686,53 @@ public class AMQConnection extends Closeable implements CommonConnection, Refere
         {
         	_logger.debug("Connected with ProtocolHandler Version:"+_protocolHandler.getProtocolVersion());
         }
-
+        notifySuccessfulConnectAttempt(lastBrokerDetails);
         _sessions.setMaxChannelID(_delegate.getMaxChannelID());
         _sessions.setMinChannelID(_delegate.getMinChannelID());
     }
 
+    private boolean repeatLastConnectAttempt(final Exception e, final BrokerDetails brokerDetails)
+    {
+        boolean repeatLastReconnectAttempt = false;
+        if (_connectAttemptListener != null)
+        {
+            final AMQException amqException;
+            if (e instanceof AMQException)
+            {
+                amqException = (AMQException) e;
+            }
+            else
+            {
+                amqException = new AMQException(ErrorCodes.CONNECTION_FORCED, e.getMessage(), e);
+            }
+
+            try
+            {
+                repeatLastReconnectAttempt = _connectAttemptListener.connectAttemptFailed(brokerDetails.getURI(), convertToJMSException(amqException));
+            }
+            catch (RuntimeException unexpected)
+            {
+                _logger.warn("Unexpected exception occurred on notifying about connect attempt failure", unexpected);
+            }
+        }
+        return repeatLastReconnectAttempt;
+    }
+
+    private void notifySuccessfulConnectAttempt(final BrokerDetails brokerDetails)
+    {
+        if (_connectAttemptListener != null)
+        {
+            try
+            {
+                _connectAttemptListener.connectAttemptSucceeded(brokerDetails.getURI());
+            }
+            catch (RuntimeException unexpected)
+            {
+                _logger.warn("Unexpected exception occurred on notifying about successful connect attempt", unexpected);
+            }
+        }
+    }
+
     private void initDelegate(ProtocolVersion pe) throws AMQProtocolException
     {
         try
@@ -753,7 +805,7 @@ public class AMQConnection extends Closeable implements CommonConnection, Refere
         try
         {
             makeBrokerConnection(bd);
-
+            notifySuccessfulConnectAttempt(bd);
             return true;
         }
         catch (Exception e)
@@ -762,8 +814,14 @@ public class AMQConnection extends Closeable implements CommonConnection, Refere
             {
                 _logger.info("Unable to connect to broker at " + bd);
             }
-
-            return useFailoverConfigOnFailure && attemptReconnection();
+            if (repeatLastConnectAttempt(e, bd))
+            {
+                return attemptReconnection(host, port, useFailoverConfigOnFailure);
+            }
+            else
+            {
+                return useFailoverConfigOnFailure && attemptReconnection();
+            }
         }
 
     }
@@ -788,6 +846,7 @@ public class AMQConnection extends Closeable implements CommonConnection, Refere
         try
         {
             makeBrokerConnection(broker);
+            notifySuccessfulConnectAttempt(broker);
             return true;
         }
         catch (Exception e)
@@ -806,6 +865,10 @@ public class AMQConnection extends Closeable implements CommonConnection, Refere
                     _logger.info(e.getMessage() + ":Unable to connect to broker at "
                                  + _failoverPolicy.getCurrentBrokerDetails());
                 }
+                if (repeatLastConnectAttempt(e, broker))
+                {
+                    return attemptConnection(broker);
+                }
             }
         }
         return false;
@@ -1356,7 +1419,8 @@ public class AMQConnection extends Closeable implements CommonConnection, Refere
 
     public String getUsername()
     {
-        return _username;
+        final String username = _username;
+        return username == null ? _connectionURL.getUsername() : username;
     }
 
     public void setUsername(String id)
@@ -1366,7 +1430,7 @@ public class AMQConnection extends Closeable implements CommonConnection, Refere
 
     public String getPassword()
     {
-        return _password;
+        return _connectionURL.getPassword();
     }
 
     public String getVirtualHost()
