@@ -30,6 +30,9 @@ import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import org.apache.qpid.configuration.ClientProperties;
 import org.apache.qpid.transport.ConnectionSettings;
 import org.apache.qpid.url.URLHelper;
@@ -37,6 +40,7 @@ import org.apache.qpid.url.URLSyntaxException;
 
 public class BrokerDetails implements Serializable
 {
+    private static final Logger LOGGER = LoggerFactory.getLogger(BrokerDetails.class);
     /*
      * Known URL Options
      * @see ConnectionURL
@@ -54,8 +58,10 @@ public class BrokerDetails implements Serializable
     public static final String OPTIONS_SASL_SERVER_NAME = "sasl_server";
     public static final String OPTIONS_TRUST_STORE = "trust_store";
     public static final String OPTIONS_TRUST_STORE_PASSWORD = "trust_store_password";
+    public static final String OPTIONS_TRUST_STORE_TYPE = "trust_store_type";
     public static final String OPTIONS_KEY_STORE = "key_store";
     public static final String OPTIONS_KEY_STORE_PASSWORD = "key_store_password";
+    public static final String OPTIONS_KEY_STORE_TYPE = "key_store_type";
     public static final String OPTIONS_SSL_VERIFY_HOSTNAME = "ssl_verify_hostname";
     public static final String OPTIONS_SSL_CERT_ALIAS = "ssl_cert_alias";
     public static final String OPTIONS_CLIENT_CERT_PRIV_KEY_PATH = "client_cert_priv_key_path";
@@ -65,9 +71,11 @@ public class BrokerDetails implements Serializable
 
     public static final String OPTIONS_ENCRYPTION_TRUST_STORE = "encryption_trust_store";
     public static final String OPTIONS_ENCRYPTION_TRUST_STORE_PASSWORD = "encryption_trust_store_password";
+    public static final String OPTIONS_ENCRYPTION_TRUST_STORE_TYPE = "encryption_trust_store_type";
     public static final String OPTIONS_ENCRYPTION_REMOTE_TRUST_STORE = "encryption_remote_trust_store";
     public static final String OPTIONS_ENCRYPTION_KEY_STORE = "encryption_key_store";
     public static final String OPTIONS_ENCRYPTION_KEY_STORE_PASSWORD = "encryption_key_store_password";
+    public static final String OPTIONS_ENCRYPTION_KEY_STORE_TYPE = "encryption_key_store_type";
 
     static final Set<String> PASSWORD_YIELDING_OPTIONS =
             Collections.unmodifiableSet(new HashSet<>(Arrays.asList(
@@ -380,7 +388,12 @@ public class BrokerDetails implements Serializable
 
     public String toString()
     {
-        StringBuffer sb = new StringBuffer();
+        return toURL(true);
+    }
+
+    private String toURL(boolean maskPasswords)
+    {
+        StringBuilder sb = new StringBuilder();
 
         sb.append(_transport);
         sb.append("://");
@@ -388,7 +401,7 @@ public class BrokerDetails implements Serializable
         sb.append(':');
         sb.append(_port);
 
-        sb.append(printOptionsURL());
+        sb.append(printOptionsURL(maskPasswords));
 
         return sb.toString();
     }
@@ -422,9 +435,9 @@ public class BrokerDetails implements Serializable
         return result;
     }
 
-    private String printOptionsURL()
+    private String printOptionsURL(boolean maskPassword)
     {
-        return URLHelper.printOptions(_options, PASSWORD_YIELDING_OPTIONS);
+        return URLHelper.printOptions(_options, maskPassword? PASSWORD_YIELDING_OPTIONS : Collections.emptySet());
     }
 
     public static String checkTransport(String broker)
@@ -488,6 +501,12 @@ public class BrokerDetails implements Serializable
                     getProperty(BrokerDetails.OPTIONS_TRUST_STORE_PASSWORD));
         }
 
+        if (getProperty(BrokerDetails.OPTIONS_TRUST_STORE_TYPE) != null)
+        {
+            conSettings.setTrustStoreType(
+                    getProperty(BrokerDetails.OPTIONS_TRUST_STORE_TYPE));
+        }
+
         if (getProperty(BrokerDetails.OPTIONS_KEY_STORE) != null)
         {
             conSettings.setKeyStorePath(
@@ -500,6 +519,12 @@ public class BrokerDetails implements Serializable
                     getProperty(BrokerDetails.OPTIONS_KEY_STORE_PASSWORD));
         }
 
+        if (getProperty(BrokerDetails.OPTIONS_KEY_STORE_TYPE) != null)
+        {
+            conSettings.setKeyStoreType(
+                    getProperty(BrokerDetails.OPTIONS_KEY_STORE_TYPE));
+        }
+
         if (getProperty(BrokerDetails.OPTIONS_SSL_CERT_ALIAS) != null)
         {
             conSettings.setCertAlias(
@@ -550,6 +575,11 @@ public class BrokerDetails implements Serializable
                     getProperty(BrokerDetails.OPTIONS_ENCRYPTION_KEY_STORE_PASSWORD));
         }
 
+        if (getProperty(BrokerDetails.OPTIONS_ENCRYPTION_KEY_STORE_TYPE) != null)
+        {
+            conSettings.setEncryptionKeyStoreType(
+                    getProperty(BrokerDetails.OPTIONS_ENCRYPTION_KEY_STORE_TYPE));
+        }
 
         if (getProperty(BrokerDetails.OPTIONS_ENCRYPTION_TRUST_STORE) != null)
         {
@@ -559,11 +589,18 @@ public class BrokerDetails implements Serializable
 
         if (getProperty(BrokerDetails.OPTIONS_ENCRYPTION_TRUST_STORE_PASSWORD) != null)
         {
-            conSettings.setEncryptionKeyStorePassword(
+            conSettings.setEncryptionTrustStorePassword(
                     getProperty(BrokerDetails.OPTIONS_ENCRYPTION_TRUST_STORE_PASSWORD));
         }
 
 
+        if (getProperty(BrokerDetails.OPTIONS_ENCRYPTION_TRUST_STORE_TYPE) != null)
+        {
+            conSettings.setEncryptionTrustStoreType(
+                    getProperty(BrokerDetails.OPTIONS_ENCRYPTION_TRUST_STORE_TYPE));
+        }
+
+
         if (getProperty(BrokerDetails.OPTIONS_ENCRYPTION_REMOTE_TRUST_STORE) != null)
         {
             conSettings.setEncryptionRemoteTrustStoreName(
@@ -596,4 +633,18 @@ public class BrokerDetails implements Serializable
     {
         _connectionUrl = connectionUrl;
     }
+
+    public URI getURI()
+    {
+        URI uri = null;
+        try
+        {
+            uri = URI.create(toURL(false));
+        }
+        catch (RuntimeException unexpected)
+        {
+            LOGGER.warn("Unexpected exception occurred on evaluation of broker URI", unexpected);
+        }
+        return uri;
+    }
 }
