@@ -20,7 +20,7 @@
  */
 package org.apache.qpid.client.message;
 
-import static org.mockito.Matchers.any;
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
@@ -95,7 +95,7 @@ public class Encrypted010MessageFactoryTest extends QpidTestCase
             Cipher cipher = Cipher.getInstance("AES/CBC/PKCS5Padding");
             cipher.init(Cipher.ENCRYPT_MODE, _secretKeySpec, new IvParameterSpec(_initializeVector));
             _encryptedMessage = cipher.doFinal(_unencrypted);
-            _keyStore = KeyStore.getInstance("jks");
+            _keyStore = KeyStore.getInstance("pkcs12");
             _keyStore.load(getClass().getClassLoader().getResourceAsStream(TestSSLConstants.KEYSTORE),
                            TestSSLConstants.KEYSTORE_PASSWORD.toCharArray());
 
